from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pparameter:
	"""Pparameter commands group definition. 12 total commands, 5 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pparameter", core, parent)

	@property
	def execute(self):
		"""execute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_execute'):
			from .Execute import Execute
			self._execute = Execute(self._core, self._base)
		return self._execute

	@property
	def pchannel(self):
		"""pchannel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pchannel'):
			from .Pchannel import Pchannel
			self._pchannel = Pchannel(self._core, self._base)
		return self._pchannel

	@property
	def piChannel(self):
		"""piChannel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_piChannel'):
			from .PiChannel import PiChannel
			self._piChannel = PiChannel(self._core, self._base)
		return self._piChannel

	@property
	def schannel(self):
		"""schannel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_schannel'):
			from .Schannel import Schannel
			self._schannel = Schannel(self._core, self._base)
		return self._schannel

	@property
	def tchannel(self):
		"""tchannel commands group. 4 Sub-classes, 2 commands."""
		if not hasattr(self, '_tchannel'):
			from .Tchannel import Tchannel
			self._tchannel = Tchannel(self._core, self._base)
		return self._tchannel

	# noinspection PyTypeChecker
	def get_crest(self) -> enums.CresFactMode:
		"""SCPI: [SOURce<HW>]:BB:C2K:PPARameter:CRESt \n
		Snippet: value: enums.CresFactMode = driver.source.bb.c2K.pparameter.get_crest() \n
		This command selects the desired range for the crest factor of the test scenario. The crest factor of the signal is kept
		in the desired range by automatically setting appropriate Walsh codes and timing offsets. The setting takes effect only
		after execution of command [:SOURce<hw>]:BB:C2K:PPARameter:EXECute.
		The setting of command [:SOURce<hw>]:BB:C2K:BSTation<st>:CGRoup<di0>:COFFset<ch>:WCODe is adjusted according to the
		selection. \n
			:return: crest: MINimum| AVERage| WORSt MINimum The crest factor is minimized. The Walsh codes are spaced as closely as possible. AVERage An average crest factor is set. The Walsh codes are distributed uniformly over the code domain. WORSt The crest factor is set to an unfavorable value (i.e. maximum) . The Walsh codes are as wildly spaced as possible.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:C2K:PPARameter:CRESt?')
		return Conversions.str_to_scalar_enum(response, enums.CresFactMode)

	def set_crest(self, crest: enums.CresFactMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:PPARameter:CRESt \n
		Snippet: driver.source.bb.c2K.pparameter.set_crest(crest = enums.CresFactMode.AVERage) \n
		This command selects the desired range for the crest factor of the test scenario. The crest factor of the signal is kept
		in the desired range by automatically setting appropriate Walsh codes and timing offsets. The setting takes effect only
		after execution of command [:SOURce<hw>]:BB:C2K:PPARameter:EXECute.
		The setting of command [:SOURce<hw>]:BB:C2K:BSTation<st>:CGRoup<di0>:COFFset<ch>:WCODe is adjusted according to the
		selection. \n
			:param crest: MINimum| AVERage| WORSt MINimum The crest factor is minimized. The Walsh codes are spaced as closely as possible. AVERage An average crest factor is set. The Walsh codes are distributed uniformly over the code domain. WORSt The crest factor is set to an unfavorable value (i.e. maximum) . The Walsh codes are as wildly spaced as possible.
		"""
		param = Conversions.enum_scalar_to_str(crest, enums.CresFactMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:PPARameter:CRESt {param}')

	# noinspection PyTypeChecker
	def get_rconfiguration(self) -> enums.Cdma2KradioConf:
		"""SCPI: [SOURce<HW>]:BB:C2K:PPARameter:RCONfiguration \n
		Snippet: value: enums.Cdma2KradioConf = driver.source.bb.c2K.pparameter.get_rconfiguration() \n
		Selects the radio configuration for the traffic channel. The setting takes effect only after execution of command
		[:SOURce<hw>]:BB:C2K:PPARameter:EXECute. \n
			:return: rconfiguration: 1| 2| 3| 4| 5
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:C2K:PPARameter:RCONfiguration?')
		return Conversions.str_to_scalar_enum(response, enums.Cdma2KradioConf)

	def set_rconfiguration(self, rconfiguration: enums.Cdma2KradioConf) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:PPARameter:RCONfiguration \n
		Snippet: driver.source.bb.c2K.pparameter.set_rconfiguration(rconfiguration = enums.Cdma2KradioConf._1) \n
		Selects the radio configuration for the traffic channel. The setting takes effect only after execution of command
		[:SOURce<hw>]:BB:C2K:PPARameter:EXECute. \n
			:param rconfiguration: 1| 2| 3| 4| 5
		"""
		param = Conversions.enum_scalar_to_str(rconfiguration, enums.Cdma2KradioConf)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:PPARameter:RCONfiguration {param}')

	def clone(self) -> 'Pparameter':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pparameter(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Niot:
	"""Niot commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("niot", core, parent)

	def get_nppwr(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:SYNC:NIOT:NPPWr \n
		Snippet: value: float = driver.source.bb.eutra.downlink.sync.niot.get_nppwr() \n
		Sets the power of the NPSS/NSSS allocations. \n
			:return: np_sync_power: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:SYNC:NIOT:NPPWr?')
		return Conversions.str_to_float(response)

	def set_nppwr(self, np_sync_power: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:SYNC:NIOT:NPPWr \n
		Snippet: driver.source.bb.eutra.downlink.sync.niot.set_nppwr(np_sync_power = 1.0) \n
		Sets the power of the NPSS/NSSS allocations. \n
			:param np_sync_power: float Range: -80 to 10
		"""
		param = Conversions.decimal_value_to_str(np_sync_power)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:SYNC:NIOT:NPPWr {param}')

	def get_ns_pwr(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:SYNC:NIOT:NSPWr \n
		Snippet: value: float = driver.source.bb.eutra.downlink.sync.niot.get_ns_pwr() \n
		Sets the power of the NPSS/NSSS allocations. \n
			:return: ns_sync_power: float Range: -80 to 10
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:SYNC:NIOT:NSPWr?')
		return Conversions.str_to_float(response)

	def set_ns_pwr(self, ns_sync_power: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:SYNC:NIOT:NSPWr \n
		Snippet: driver.source.bb.eutra.downlink.sync.niot.set_ns_pwr(ns_sync_power = 1.0) \n
		Sets the power of the NPSS/NSSS allocations. \n
			:param ns_sync_power: float Range: -80 to 10
		"""
		param = Conversions.decimal_value_to_str(ns_sync_power)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:SYNC:NIOT:NSPWr {param}')

	# noinspection PyTypeChecker
	def get_tx_antenna(self) -> enums.EutraNbiotSimAnt:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:SYNC:NIOT:TXANtenna \n
		Snippet: value: enums.EutraNbiotSimAnt = driver.source.bb.eutra.downlink.sync.niot.get_tx_antenna() \n
		Defines on which antenna the NPSS/NSSS are transmitted. \n
			:return: np_ns_sync_tx_ant: NONE| ANT1| ANT2| ALL
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:SYNC:NIOT:TXANtenna?')
		return Conversions.str_to_scalar_enum(response, enums.EutraNbiotSimAnt)

	def set_tx_antenna(self, np_ns_sync_tx_ant: enums.EutraNbiotSimAnt) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:SYNC:NIOT:TXANtenna \n
		Snippet: driver.source.bb.eutra.downlink.sync.niot.set_tx_antenna(np_ns_sync_tx_ant = enums.EutraNbiotSimAnt.ALL) \n
		Defines on which antenna the NPSS/NSSS are transmitted. \n
			:param np_ns_sync_tx_ant: NONE| ANT1| ANT2| ALL
		"""
		param = Conversions.enum_scalar_to_str(np_ns_sync_tx_ant, enums.EutraNbiotSimAnt)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:SYNC:NIOT:TXANtenna {param}')



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Setting:
	"""Setting commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("setting", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:DVB:SETTing:CATalog \n
		Snippet: value: List[str] = driver.source.bb.dvb.setting.get_catalog() \n
		Queries the files with settings in the default directory. Listed are files with the file extension *.dvb.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:return: catalog: filename1,filename2,... Returns a string of filenames separated by commas.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:SETTing:CATalog?')
		return Conversions.str_to_str_list(response)

	def delete(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:SETTing:DELete \n
		Snippet: driver.source.bb.dvb.setting.delete(filename = '1') \n
		Deletes the selected file from the default or specified directory. Deleted are files with the file extension *.dvb. Refer
		to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default and in
		a specific directory. \n
			:param filename: string Filename or complete file path; file extension can be omitted
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:SETTing:DELete {param}')

	def load(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:SETTing:LOAD \n
		Snippet: driver.source.bb.dvb.setting.load(filename = '1') \n
		Loads the selected file from the default or the specified directory. Loaded are files with extension *.dvb.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param filename: string Filename or complete file path; file extension can be omitted
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:SETTing:LOAD {param}')

	def set_store(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:SETTing:STORe \n
		Snippet: driver.source.bb.dvb.setting.set_store(filename = '1') \n
		Saves the current settings into the selected file; the file extension (*.dvb) is assigned automatically.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param filename: string Filename or complete file path
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:SETTing:STORe {param}')



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from ..........Internal.Utilities import trim_str_response
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dselect:
	"""Dselect commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dselect", core, parent)

	def set(self, dselect: str, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:HSDPa:HSET:DATA:DSELect \n
		Snippet: driver.source.bb.w3Gpp.bstation.channel.hsdpa.hset.data.dselect.set(dselect = '1', baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		The command selects the data list for the DLISt data source selection. The lists are stored as files with the fixed file
		extensions *.dm_iqd in a directory of the user's choice. The directory applicable to the following commands is defined
		with the command method RsSmw.MassMemory.currentDirectory. To access the files in this directory, you only have to give
		the file name, without the path and the file extension. \n
			:param dselect: string
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')"""
		param = Conversions.value_to_quoted_str(dselect)
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:HSDPa:HSET:DATA:DSELect {param}')

	def get(self, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:HSDPa:HSET:DATA:DSELect \n
		Snippet: value: str = driver.source.bb.w3Gpp.bstation.channel.hsdpa.hset.data.dselect.get(baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		The command selects the data list for the DLISt data source selection. The lists are stored as files with the fixed file
		extensions *.dm_iqd in a directory of the user's choice. The directory applicable to the following commands is defined
		with the command method RsSmw.MassMemory.currentDirectory. To access the files in this directory, you only have to give
		the file name, without the path and the file extension. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: dselect: string"""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:HSDPa:HSET:DATA:DSELect?')
		return trim_str_response(response)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mcs:
	"""Mcs commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mcs", core, parent)

	def set(self, mcs: int, subframeNull=repcap.SubframeNull.Default, itemNull=repcap.ItemNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:DL:[SUBF<ST0>]:ENCC:PDCCh:EXTC:ITEM<CH0>:DCIConf:FIRStrans:MCS \n
		Snippet: driver.source.bb.oneweb.downlink.subf.encc.pdcch.extc.item.dciConf.firstTrans.mcs.set(mcs = 1, subframeNull = repcap.SubframeNull.Default, itemNull = repcap.ItemNull.Default) \n
		PDCCH DCI <Modulation and Coding Scheme> - First Transmission \n
			:param mcs: integer Range: 0 to 31
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param itemNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Item')"""
		param = Conversions.decimal_value_to_str(mcs)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		itemNull_cmd_val = self._base.get_repcap_cmd_value(itemNull, repcap.ItemNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:DL:SUBF{subframeNull_cmd_val}:ENCC:PDCCh:EXTC:ITEM{itemNull_cmd_val}:DCIConf:FIRStrans:MCS {param}')

	def get(self, subframeNull=repcap.SubframeNull.Default, itemNull=repcap.ItemNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:DL:[SUBF<ST0>]:ENCC:PDCCh:EXTC:ITEM<CH0>:DCIConf:FIRStrans:MCS \n
		Snippet: value: int = driver.source.bb.oneweb.downlink.subf.encc.pdcch.extc.item.dciConf.firstTrans.mcs.get(subframeNull = repcap.SubframeNull.Default, itemNull = repcap.ItemNull.Default) \n
		PDCCH DCI <Modulation and Coding Scheme> - First Transmission \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param itemNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Item')
			:return: mcs: integer Range: 0 to 31"""
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		itemNull_cmd_val = self._base.get_repcap_cmd_value(itemNull, repcap.ItemNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ONEWeb:DL:SUBF{subframeNull_cmd_val}:ENCC:PDCCh:EXTC:ITEM{itemNull_cmd_val}:DCIConf:FIRStrans:MCS?')
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Reference:
	"""Reference commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("reference", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce]:POWer:LEVel:VIA:REFerence:STATe \n
		Snippet: value: bool = driver.source.power.level.via.reference.get_state() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('SOURce:POWer:LEVel:VIA:REFerence:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce]:POWer:LEVel:VIA:REFerence:STATe \n
		Snippet: driver.source.power.level.via.reference.set_state(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce:POWer:LEVel:VIA:REFerence:STATe {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("data", core, parent)

	def set(self, data: enums.DataSourceA, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:UL:UE<ST>:[CELL<CCIDX>]:PUACh:DATA \n
		Snippet: driver.source.bb.oneweb.uplink.ue.cell.puach.data.set(data = enums.DataSourceA.DLISt, userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default) \n
		Selects the PUSCH/PUACH data source of the selected UE. For the selected UE, this data source is used for the PUSCH/PUACH
		channel in every subframe where this channel is configured. \n
			:param data: PN9| PN11| PN15| PN16| PN20| PN21| PN23| PATTern| DLISt| ZERO| ONE
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')"""
		param = Conversions.enum_scalar_to_str(data, enums.DataSourceA)
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:PUACh:DATA {param}')

	# noinspection PyTypeChecker
	def get(self, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default) -> enums.DataSourceA:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:UL:UE<ST>:[CELL<CCIDX>]:PUACh:DATA \n
		Snippet: value: enums.DataSourceA = driver.source.bb.oneweb.uplink.ue.cell.puach.data.get(userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default) \n
		Selects the PUSCH/PUACH data source of the selected UE. For the selected UE, this data source is used for the PUSCH/PUACH
		channel in every subframe where this channel is configured. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: data: PN9| PN11| PN15| PN16| PN20| PN21| PN23| PATTern| DLISt| ZERO| ONE"""
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ONEWeb:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:PUACh:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.DataSourceA)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CycPrefix:
	"""CycPrefix commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cycPrefix", core, parent)

	def set(self, cyclic_prefix: enums.EuTraDuration, subframeNull=repcap.SubframeNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:UL:[SUBF<ST0>]:CYCPrefix \n
		Snippet: driver.source.bb.oneweb.uplink.subf.cycPrefix.set(cyclic_prefix = enums.EuTraDuration.EXTended, subframeNull = repcap.SubframeNull.Default) \n
		No command help available \n
			:param cyclic_prefix: No help available
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')"""
		param = Conversions.enum_scalar_to_str(cyclic_prefix, enums.EuTraDuration)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:UL:SUBF{subframeNull_cmd_val}:CYCPrefix {param}')

	# noinspection PyTypeChecker
	def get(self, subframeNull=repcap.SubframeNull.Default) -> enums.EuTraDuration:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:UL:[SUBF<ST0>]:CYCPrefix \n
		Snippet: value: enums.EuTraDuration = driver.source.bb.oneweb.uplink.subf.cycPrefix.get(subframeNull = repcap.SubframeNull.Default) \n
		No command help available \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:return: cyclic_prefix: No help available"""
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ONEWeb:UL:SUBF{subframeNull_cmd_val}:CYCPrefix?')
		return Conversions.str_to_scalar_enum(response, enums.EuTraDuration)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UpInterval:
	"""UpInterval commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("upInterval", core, parent)

	def get(self, objectIx=repcap.ObjectIx.Default) -> float:
		"""SCPI: [SOURce<HW>]:REGenerator:OBJect<CH>:RCS:UPINterval \n
		Snippet: value: float = driver.source.regenerator.object.rcs.upInterval.get(objectIx = repcap.ObjectIx.Default) \n
		Queries how often a new swerling random value is created. \n
			:param objectIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Object')
			:return: rcs_update_interv: float Range: 3.74742E-5 to 3600"""
		objectIx_cmd_val = self._base.get_repcap_cmd_value(objectIx, repcap.ObjectIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:REGenerator:OBJect{objectIx_cmd_val}:RCS:UPINterval?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Plci:
	"""Plci commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("plci", core, parent)

	def get_cid(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:[PLCI]:CID \n
		Snippet: value: int = driver.source.bb.eutra.uplink.plci.get_cid() \n
		Sets the cell identity. \n
			:return: cell_id: integer Range: 0 to 503
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:UL:PLCI:CID?')
		return Conversions.str_to_int(response)

	def set_cid(self, cell_id: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:[PLCI]:CID \n
		Snippet: driver.source.bb.eutra.uplink.plci.set_cid(cell_id = 1) \n
		Sets the cell identity. \n
			:param cell_id: integer Range: 0 to 503
		"""
		param = Conversions.decimal_value_to_str(cell_id)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:PLCI:CID {param}')

	def get_cid_group(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:[PLCI]:CIDGroup \n
		Snippet: value: int = driver.source.bb.eutra.uplink.plci.get_cid_group() \n
		Sets the ID of the physical cell identity group. \n
			:return: phys_cell_id_group: integer Range: 0 to 167
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:UL:PLCI:CIDGroup?')
		return Conversions.str_to_int(response)

	def set_cid_group(self, phys_cell_id_group: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:[PLCI]:CIDGroup \n
		Snippet: driver.source.bb.eutra.uplink.plci.set_cid_group(phys_cell_id_group = 1) \n
		Sets the ID of the physical cell identity group. \n
			:param phys_cell_id_group: integer Range: 0 to 167
		"""
		param = Conversions.decimal_value_to_str(phys_cell_id_group)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:PLCI:CIDGroup {param}')

	def get_plid(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:[PLCI]:PLID \n
		Snippet: value: int = driver.source.bb.eutra.uplink.plci.get_plid() \n
		Sets the identity of the physical layer within the selected physical cell identity group, set with the command
		[:SOURce<hw>]:BB:EUTRa:UL[:PLCI]:CIDGroup. \n
			:return: physical_layer_id: integer Range: 0 to 2
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:UL:PLCI:PLID?')
		return Conversions.str_to_int(response)

	def set_plid(self, physical_layer_id: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:[PLCI]:PLID \n
		Snippet: driver.source.bb.eutra.uplink.plci.set_plid(physical_layer_id = 1) \n
		Sets the identity of the physical layer within the selected physical cell identity group, set with the command
		[:SOURce<hw>]:BB:EUTRa:UL[:PLCI]:CIDGroup. \n
			:param physical_layer_id: integer Range: 0 to 2
		"""
		param = Conversions.decimal_value_to_str(physical_layer_id)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:PLCI:PLID {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Gain:
	"""Gain commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("gain", core, parent)

	def get_rx(self) -> float:
		"""SCPI: [SOURce<HW>]:REGenerator:RADar:ANTenna:REG:GAIN:RX \n
		Snippet: value: float = driver.source.regenerator.radar.antenna.reg.gain.get_rx() \n
		Sets the antenna gain. \n
			:return: gain_rx: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:REGenerator:RADar:ANTenna:REG:GAIN:RX?')
		return Conversions.str_to_float(response)

	def set_rx(self, gain_rx: float) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:RADar:ANTenna:REG:GAIN:RX \n
		Snippet: driver.source.regenerator.radar.antenna.reg.gain.set_rx(gain_rx = 1.0) \n
		Sets the antenna gain. \n
			:param gain_rx: float Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(gain_rx)
		self._core.io.write(f'SOURce<HwInstance>:REGenerator:RADar:ANTenna:REG:GAIN:RX {param}')

	def get_tx(self) -> float:
		"""SCPI: [SOURce<HW>]:REGenerator:RADar:ANTenna:REG:GAIN:TX \n
		Snippet: value: float = driver.source.regenerator.radar.antenna.reg.gain.get_tx() \n
		Sets the antenna gain. \n
			:return: gain_tx: float Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:REGenerator:RADar:ANTenna:REG:GAIN:TX?')
		return Conversions.str_to_float(response)

	def set_tx(self, gain_tx: float) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:RADar:ANTenna:REG:GAIN:TX \n
		Snippet: driver.source.regenerator.radar.antenna.reg.gain.set_tx(gain_tx = 1.0) \n
		Sets the antenna gain. \n
			:param gain_tx: float Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(gain_tx)
		self._core.io.write(f'SOURce<HwInstance>:REGenerator:RADar:ANTenna:REG:GAIN:TX {param}')



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class E1Os:
	"""E1Os commands group definition. 10 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("e1Os", core, parent)

	@property
	def data(self):
		"""data commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_data'):
			from .Data import Data
			self._data = Data(self._core, self._base)
		return self._data

	@property
	def pilot(self):
		"""pilot commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_pilot'):
			from .Pilot import Pilot
			self._pilot = Pilot(self._core, self._base)
		return self._pilot

	@property
	def power(self):
		"""power commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	def clone(self) -> 'E1Os':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = E1Os(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Eucc:
	"""Eucc commands group definition. 4 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("eucc", core, parent)

	@property
	def ccount(self):
		"""ccount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ccount'):
			from .Ccount import Ccount
			self._ccount = Ccount(self._core, self._base)
		return self._ccount

	@property
	def hpid(self):
		"""hpid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hpid'):
			from .Hpid import Hpid
			self._hpid = Hpid(self._core, self._base)
		return self._hpid

	@property
	def rsNumber(self):
		"""rsNumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rsNumber'):
			from .RsNumber import RsNumber
			self._rsNumber = RsNumber(self._core, self._base)
		return self._rsNumber

	@property
	def tfci(self):
		"""tfci commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tfci'):
			from .Tfci import Tfci
			self._tfci = Tfci(self._core, self._base)
		return self._tfci

	def clone(self) -> 'Eucc':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Eucc(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LdMrs:
	"""LdMrs commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ldMrs", core, parent)

	def set(self, up_pts_less_dmrs: bool, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:[CELL<CCIDX>]:PUSCh:UPPTs:LDMRs \n
		Snippet: driver.source.bb.eutra.uplink.ue.cell.pusch.uppts.ldMrs.set(up_pts_less_dmrs = False, userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default) \n
		If enabled, the number of used demodulation reference signals (DMRS) is reduced. \n
			:param up_pts_less_dmrs: 0| 1| OFF| ON
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')"""
		param = Conversions.bool_to_str(up_pts_less_dmrs)
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:PUSCh:UPPTs:LDMRs {param}')

	def get(self, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:[CELL<CCIDX>]:PUSCh:UPPTs:LDMRs \n
		Snippet: value: bool = driver.source.bb.eutra.uplink.ue.cell.pusch.uppts.ldMrs.get(userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default) \n
		If enabled, the number of used demodulation reference signals (DMRS) is reduced. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: up_pts_less_dmrs: 0| 1| OFF| ON"""
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:PUSCh:UPPTs:LDMRs?')
		return Conversions.str_to_bool(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Store:
	"""Store commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("store", core, parent)

	def set(self, filename: str, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:CCODing:USER:STORe \n
		Snippet: driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.ccoding.user.store.set(filename = '1', channelNull = repcap.ChannelNull.Default) \n
		The command saves the current settings for channel coding as user channel coding in the specified file. The files are
		stored with the fixed file extensions *.3g_ccod_dl in a directory of the user's choice. The directory in which the file
		is stored is defined with the command method RsSmw.MassMemory.currentDirectory. To store the files in this directory, you
		only have to give the file name, without the path and the file extension. \n
			:param filename: string
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')"""
		param = Conversions.value_to_quoted_str(filename)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:CCODing:USER:STORe {param}')



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SfStart:
	"""SfStart commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sfStart", core, parent)

	def set(self, starting_sf: int, userEquipment=repcap.UserEquipment.Default, attenuationNull=repcap.AttenuationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:PRACh:ATT<CH0>:EMTC:SFSTart \n
		Snippet: driver.source.bb.eutra.uplink.ue.prach.att.emtc.sfStart.set(starting_sf = 1, userEquipment = repcap.UserEquipment.Default, attenuationNull = repcap.AttenuationNull.Default) \n
		Sets the starting subframe. \n
			:param starting_sf: integer Range: 0 to 1E5
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param attenuationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Att')"""
		param = Conversions.decimal_value_to_str(starting_sf)
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		attenuationNull_cmd_val = self._base.get_repcap_cmd_value(attenuationNull, repcap.AttenuationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:PRACh:ATT{attenuationNull_cmd_val}:EMTC:SFSTart {param}')

	def get(self, userEquipment=repcap.UserEquipment.Default, attenuationNull=repcap.AttenuationNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:PRACh:ATT<CH0>:EMTC:SFSTart \n
		Snippet: value: int = driver.source.bb.eutra.uplink.ue.prach.att.emtc.sfStart.get(userEquipment = repcap.UserEquipment.Default, attenuationNull = repcap.AttenuationNull.Default) \n
		Sets the starting subframe. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param attenuationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Att')
			:return: starting_sf: integer Range: 0 to 1E5"""
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		attenuationNull_cmd_val = self._base.get_repcap_cmd_value(attenuationNull, repcap.AttenuationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:PRACh:ATT{attenuationNull_cmd_val}:EMTC:SFSTart?')
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Altitude:
	"""Altitude commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("altitude", core, parent)

	def get_cruise(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:ALTitude:CRUise \n
		Snippet: value: float = driver.source.fsimulator.dsSimulation.towerToAir.altitude.get_cruise() \n
		No command help available \n
			:return: altitude_cruise: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:ALTitude:CRUise?')
		return Conversions.str_to_float(response)

	def set_cruise(self, altitude_cruise: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:ALTitude:CRUise \n
		Snippet: driver.source.fsimulator.dsSimulation.towerToAir.altitude.set_cruise(altitude_cruise = 1.0) \n
		No command help available \n
			:param altitude_cruise: No help available
		"""
		param = Conversions.decimal_value_to_str(altitude_cruise)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:ALTitude:CRUise {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frame:
	"""Frame commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frame", core, parent)

	def set(self, frame: int, output=repcap.Output.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GSM:TRIGger:OUTPut<CH>:PERiod:[FRAMe] \n
		Snippet: driver.source.bb.gsm.trigger.output.period.frame.set(frame = 1, output = repcap.Output.Default) \n
		Sets the repetition rate for the frame clock at the marker outputs. \n
			:param frame: integer Range: 1 to 67108863
			:param output: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')"""
		param = Conversions.decimal_value_to_str(frame)
		output_cmd_val = self._base.get_repcap_cmd_value(output, repcap.Output)
		self._core.io.write(f'SOURce<HwInstance>:BB:GSM:TRIGger:OUTPut{output_cmd_val}:PERiod:FRAMe {param}')

	def get(self, output=repcap.Output.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:GSM:TRIGger:OUTPut<CH>:PERiod:[FRAMe] \n
		Snippet: value: int = driver.source.bb.gsm.trigger.output.period.frame.get(output = repcap.Output.Default) \n
		Sets the repetition rate for the frame clock at the marker outputs. \n
			:param output: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: frame: integer Range: 1 to 67108863"""
		output_cmd_val = self._base.get_repcap_cmd_value(output, repcap.Output)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GSM:TRIGger:OUTPut{output_cmd_val}:PERiod:FRAMe?')
		return Conversions.str_to_int(response)



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal import Conversions
from ............ import enums
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CbSymbol:
	"""CbSymbol commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cbSymbol", core, parent)

	def set(self, dci_cb_symb_ind: enums.V5GdCiCbSym, subframeNull=repcap.SubframeNull.Default, itemNull=repcap.ItemNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:[SUBF<ST0>]:ENCC:XPDCch:EXTC:ITEM<CH0>:DCIConf:CBSYmbol \n
		Snippet: driver.source.bb.v5G.downlink.subf.encc.xpdcch.extc.item.dciConf.cbSymbol.set(dci_cb_symb_ind = enums.V5GdCiCbSym.S12, subframeNull = repcap.SubframeNull.Default, itemNull = repcap.ItemNull.Default) \n
		Sets the DCI format field OFDM symbol index for CSI-RS / BRRS. \n
			:param dci_cb_symb_ind: S12| S13| S1213 13th symbol, 14th symbol, 13th and 14th symbol
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param itemNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Item')"""
		param = Conversions.enum_scalar_to_str(dci_cb_symb_ind, enums.V5GdCiCbSym)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		itemNull_cmd_val = self._base.get_repcap_cmd_value(itemNull, repcap.ItemNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:DL:SUBF{subframeNull_cmd_val}:ENCC:XPDCch:EXTC:ITEM{itemNull_cmd_val}:DCIConf:CBSYmbol {param}')

	# noinspection PyTypeChecker
	def get(self, subframeNull=repcap.SubframeNull.Default, itemNull=repcap.ItemNull.Default) -> enums.V5GdCiCbSym:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:[SUBF<ST0>]:ENCC:XPDCch:EXTC:ITEM<CH0>:DCIConf:CBSYmbol \n
		Snippet: value: enums.V5GdCiCbSym = driver.source.bb.v5G.downlink.subf.encc.xpdcch.extc.item.dciConf.cbSymbol.get(subframeNull = repcap.SubframeNull.Default, itemNull = repcap.ItemNull.Default) \n
		Sets the DCI format field OFDM symbol index for CSI-RS / BRRS. \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param itemNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Item')
			:return: dci_cb_symb_ind: S12| S13| S1213 13th symbol, 14th symbol, 13th and 14th symbol"""
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		itemNull_cmd_val = self._base.get_repcap_cmd_value(itemNull, repcap.ItemNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:V5G:DL:SUBF{subframeNull_cmd_val}:ENCC:XPDCch:EXTC:ITEM{itemNull_cmd_val}:DCIConf:CBSYmbol?')
		return Conversions.str_to_scalar_enum(response, enums.V5GdCiCbSym)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Output:
	"""Output commands group definition. 3 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("output", core, parent)

	@property
	def bbmm(self):
		"""bbmm commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_bbmm'):
			from .Bbmm import Bbmm
			self._bbmm = Bbmm(self._core, self._base)
		return self._bbmm

	@property
	def rf(self):
		"""rf commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rf'):
			from .Rf import Rf
			self._rf = Rf(self._core, self._base)
		return self._rf

	def set(self, output: enums.Output, stream=repcap.Stream.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:STReam<ST>:OUTPut \n
		Snippet: driver.source.bb.gnss.stream.output.set(output = enums.Output.NONE, stream = repcap.Stream.Default) \n
		Sets the output connector to that the output GNSS signal is routed. \n
			:param output: RFA| RFB| NONE
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Stream')"""
		param = Conversions.enum_scalar_to_str(output, enums.Output)
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:STReam{stream_cmd_val}:OUTPut {param}')

	# noinspection PyTypeChecker
	def get(self, stream=repcap.Stream.Default) -> enums.Output:
		"""SCPI: [SOURce<HW>]:BB:GNSS:STReam<ST>:OUTPut \n
		Snippet: value: enums.Output = driver.source.bb.gnss.stream.output.get(stream = repcap.Stream.Default) \n
		Sets the output connector to that the output GNSS signal is routed. \n
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Stream')
			:return: output: RFA| RFB| NONE"""
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:STReam{stream_cmd_val}:OUTPut?')
		return Conversions.str_to_scalar_enum(response, enums.Output)

	def clone(self) -> 'Output':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Output(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Soffset:
	"""Soffset commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("soffset", core, parent)

	def set(self, soffset: int, mobileStation=repcap.MobileStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:PRACh:TIMing:SOFFset \n
		Snippet: driver.source.bb.w3Gpp.mstation.prach.timing.soffset.set(soffset = 1, mobileStation = repcap.MobileStation.Default) \n
		This command defines the start offset of the PRACH in access slots. The starting time delay in timeslots is calculated
		according to: 2 x Start Offset. \n
			:param soffset: integer Range: 1 to 50
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')"""
		param = Conversions.decimal_value_to_str(soffset)
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:PRACh:TIMing:SOFFset {param}')

	def get(self, mobileStation=repcap.MobileStation.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:PRACh:TIMing:SOFFset \n
		Snippet: value: int = driver.source.bb.w3Gpp.mstation.prach.timing.soffset.get(mobileStation = repcap.MobileStation.Default) \n
		This command defines the start offset of the PRACH in access slots. The starting time delay in timeslots is calculated
		according to: 2 x Start Offset. \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:return: soffset: integer Range: 1 to 50"""
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:PRACh:TIMing:SOFFset?')
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Scheduling:
	"""Scheduling commands group definition. 426 total commands, 2 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("scheduling", core, parent)

	@property
	def cell(self):
		"""cell commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_cell'):
			from .Cell import Cell
			self._cell = Cell(self._core, self._base)
		return self._cell

	@property
	def sfn(self):
		"""sfn commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfn'):
			from .Sfn import Sfn
			self._sfn = Sfn(self._core, self._base)
		return self._sfn

	def get_ncarrier(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:NCARrier \n
		Snippet: value: int = driver.source.bb.nr5G.scheduling.get_ncarrier() \n
		No command help available \n
			:return: num_sched_carrier: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:SCHed:NCARrier?')
		return Conversions.str_to_int(response)

	def set_ncarrier(self, num_sched_carrier: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:NCARrier \n
		Snippet: driver.source.bb.nr5G.scheduling.set_ncarrier(num_sched_carrier = 1) \n
		No command help available \n
			:param num_sched_carrier: No help available
		"""
		param = Conversions.decimal_value_to_str(num_sched_carrier)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:SCHed:NCARrier {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.AutoManualMode:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHeduling:MODE \n
		Snippet: value: enums.AutoManualMode = driver.source.bb.nr5G.scheduling.get_mode() \n
		Defines how the scheduling and the content of the different PDSCH allocations is defined and performed. \n
			:return: scheduling_mode: MANual| AUTO MANual No cross-reference between the settings made for the CORESET DCIs and the PDSCHs settings. Configure the PDSCH allocations manually. AUTO Content and scheduling of the PDSCH according to the configuration of the CORESET DCIs.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:SCHeduling:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)

	def set_mode(self, scheduling_mode: enums.AutoManualMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHeduling:MODE \n
		Snippet: driver.source.bb.nr5G.scheduling.set_mode(scheduling_mode = enums.AutoManualMode.AUTO) \n
		Defines how the scheduling and the content of the different PDSCH allocations is defined and performed. \n
			:param scheduling_mode: MANual| AUTO MANual No cross-reference between the settings made for the CORESET DCIs and the PDSCHs settings. Configure the PDSCH allocations manually. AUTO Content and scheduling of the PDSCH according to the configuration of the CORESET DCIs.
		"""
		param = Conversions.enum_scalar_to_str(scheduling_mode, enums.AutoManualMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:SCHeduling:MODE {param}')

	def get_rs_space(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHeduling:RSSPace \n
		Snippet: value: bool = driver.source.bb.nr5G.scheduling.get_rs_space() \n
		If enabled, the CCE start index is selected automatically to be within the current search space. \n
			:return: restr_to_sspace: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:SCHeduling:RSSPace?')
		return Conversions.str_to_bool(response)

	def set_rs_space(self, restr_to_sspace: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHeduling:RSSPace \n
		Snippet: driver.source.bb.nr5G.scheduling.set_rs_space(restr_to_sspace = False) \n
		If enabled, the CCE start index is selected automatically to be within the current search space. \n
			:param restr_to_sspace: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(restr_to_sspace)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:SCHeduling:RSSPace {param}')

	def clone(self) -> 'Scheduling':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Scheduling(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ApMap:
	"""ApMap commands group definition. 10 total commands, 10 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("apMap", core, parent)

	@property
	def ap100Map(self):
		"""ap100Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap100Map'):
			from .Ap100Map import Ap100Map
			self._ap100Map = Ap100Map(self._core, self._base)
		return self._ap100Map

	@property
	def ap10Map(self):
		"""ap10Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap10Map'):
			from .Ap10Map import Ap10Map
			self._ap10Map = Ap10Map(self._core, self._base)
		return self._ap10Map

	@property
	def ap200Map(self):
		"""ap200Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap200Map'):
			from .Ap200Map import Ap200Map
			self._ap200Map = Ap200Map(self._core, self._base)
		return self._ap200Map

	@property
	def ap201Map(self):
		"""ap201Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap201Map'):
			from .Ap201Map import Ap201Map
			self._ap201Map = Ap201Map(self._core, self._base)
		return self._ap201Map

	@property
	def ap20Map(self):
		"""ap20Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap20Map'):
			from .Ap20Map import Ap20Map
			self._ap20Map = Ap20Map(self._core, self._base)
		return self._ap20Map

	@property
	def ap21Map(self):
		"""ap21Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap21Map'):
			from .Ap21Map import Ap21Map
			self._ap21Map = Ap21Map(self._core, self._base)
		return self._ap21Map

	@property
	def ap40Map(self):
		"""ap40Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap40Map'):
			from .Ap40Map import Ap40Map
			self._ap40Map = Ap40Map(self._core, self._base)
		return self._ap40Map

	@property
	def ap41Map(self):
		"""ap41Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap41Map'):
			from .Ap41Map import Ap41Map
			self._ap41Map = Ap41Map(self._core, self._base)
		return self._ap41Map

	@property
	def ap42Map(self):
		"""ap42Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap42Map'):
			from .Ap42Map import Ap42Map
			self._ap42Map = Ap42Map(self._core, self._base)
		return self._ap42Map

	@property
	def ap43Map(self):
		"""ap43Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap43Map'):
			from .Ap43Map import Ap43Map
			self._ap43Map = Ap43Map(self._core, self._base)
		return self._ap43Map

	def clone(self) -> 'ApMap':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ApMap(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Globale:
	"""Globale commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("globale", core, parent)

	def get_seed(self) -> int:
		"""SCPI: [SOURce<HW>]:FSIMulator:GLOBal:SEED \n
		Snippet: value: int = driver.source.fsimulator.globale.get_seed() \n
		This command enters the fading start seed. This value is global for the instrument. \n
			:return: seed: integer Range: 0 to 9
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:GLOBal:SEED?')
		return Conversions.str_to_int(response)

	def set_seed(self, seed: int) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:GLOBal:SEED \n
		Snippet: driver.source.fsimulator.globale.set_seed(seed = 1) \n
		This command enters the fading start seed. This value is global for the instrument. \n
			:param seed: integer Range: 0 to 9
		"""
		param = Conversions.decimal_value_to_str(seed)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:GLOBal:SEED {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Prach:
	"""Prach commands group definition. 25 total commands, 15 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("prach", core, parent)

	@property
	def aslot(self):
		"""aslot commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aslot'):
			from .Aslot import Aslot
			self._aslot = Aslot(self._core, self._base)
		return self._aslot

	@property
	def atTiming(self):
		"""atTiming commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_atTiming'):
			from .AtTiming import AtTiming
			self._atTiming = AtTiming(self._core, self._base)
		return self._atTiming

	@property
	def cpower(self):
		"""cpower commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cpower'):
			from .Cpower import Cpower
			self._cpower = Cpower(self._core, self._base)
		return self._cpower

	@property
	def data(self):
		"""data commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import Data
			self._data = Data(self._core, self._base)
		return self._data

	@property
	def dpower(self):
		"""dpower commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dpower'):
			from .Dpower import Dpower
			self._dpower = Dpower(self._core, self._base)
		return self._dpower

	@property
	def mlength(self):
		"""mlength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mlength'):
			from .Mlength import Mlength
			self._mlength = Mlength(self._core, self._base)
		return self._mlength

	@property
	def ppower(self):
		"""ppower commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_ppower'):
			from .Ppower import Ppower
			self._ppower = Ppower(self._core, self._base)
		return self._ppower

	@property
	def prepetition(self):
		"""prepetition commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prepetition'):
			from .Prepetition import Prepetition
			self._prepetition = Prepetition(self._core, self._base)
		return self._prepetition

	@property
	def rafter(self):
		"""rafter commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rafter'):
			from .Rafter import Rafter
			self._rafter = Rafter(self._core, self._base)
		return self._rafter

	@property
	def rarb(self):
		"""rarb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rarb'):
			from .Rarb import Rarb
			self._rarb = Rarb(self._core, self._base)
		return self._rarb

	@property
	def sformat(self):
		"""sformat commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sformat'):
			from .Sformat import Sformat
			self._sformat = Sformat(self._core, self._base)
		return self._sformat

	@property
	def signature(self):
		"""signature commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_signature'):
			from .Signature import Signature
			self._signature = Signature(self._core, self._base)
		return self._signature

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRate
			self._symbolRate = SymbolRate(self._core, self._base)
		return self._symbolRate

	@property
	def tfci(self):
		"""tfci commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tfci'):
			from .Tfci import Tfci
			self._tfci = Tfci(self._core, self._base)
		return self._tfci

	@property
	def timing(self):
		"""timing commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_timing'):
			from .Timing import Timing
			self._timing = Timing(self._core, self._base)
		return self._timing

	def clone(self) -> 'Prach':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Prach(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Gain:
	"""Gain commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("gain", core, parent)

	def get(self, cluster=repcap.Cluster.Default, mimoTap=repcap.MimoTap.Default, subCluster=repcap.SubCluster.Default) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:SCWI:CLUSter<CH>:TAP<ST>:SUBCluster<DI>:GAIN \n
		Snippet: value: float = driver.source.fsimulator.mimo.scwi.cluster.tap.subCluster.gain.get(cluster = repcap.Cluster.Default, mimoTap = repcap.MimoTap.Default, subCluster = repcap.SubCluster.Default) \n
		Queries the resulting relative gain of an enabled sub-cluster. \n
			:param cluster: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cluster')
			:param mimoTap: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tap')
			:param subCluster: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubCluster')
			:return: gain: float Range: -50 to 0"""
		cluster_cmd_val = self._base.get_repcap_cmd_value(cluster, repcap.Cluster)
		mimoTap_cmd_val = self._base.get_repcap_cmd_value(mimoTap, repcap.MimoTap)
		subCluster_cmd_val = self._base.get_repcap_cmd_value(subCluster, repcap.SubCluster)
		response = self._core.io.query_str(f'SOURce<HwInstance>:FSIMulator:MIMO:SCWI:CLUSter{cluster_cmd_val}:TAP{mimoTap_cmd_val}:SUBCluster{subCluster_cmd_val}:GAIN?')
		return Conversions.str_to_float(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Interleaver:
	"""Interleaver commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("interleaver", core, parent)

	def set(self, interleaver: bool, channelNull=repcap.ChannelNull.Default, transportChannelNull=repcap.TransportChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:TCHannel<DI0>:INTerleaver \n
		Snippet: driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.tchannel.interleaver.set(interleaver = False, channelNull = repcap.ChannelNull.Default, transportChannelNull = repcap.TransportChannelNull.Default) \n
		The command activates or deactivates channel coding interleaver state 1 for the selected channel. Interleaver state 1 can
		be activated and deactivated for each transport channel individually. The channel is selected via the suffix at TCHannel.
		Interleaver state 2 can only be activated or deactivated for all the transport channels together
		([:SOURce<hw>]:BB:W3GPp:BSTation:ENHanced:CHANnel<ch0>:DPCH:INTerleaver2) . Note: The interleaver states do not cause the
		symbol rate to change. \n
			:param interleaver: ON| OFF
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:param transportChannelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Tchannel')"""
		param = Conversions.bool_to_str(interleaver)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		transportChannelNull_cmd_val = self._base.get_repcap_cmd_value(transportChannelNull, repcap.TransportChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:TCHannel{transportChannelNull_cmd_val}:INTerleaver {param}')

	def get(self, channelNull=repcap.ChannelNull.Default, transportChannelNull=repcap.TransportChannelNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:TCHannel<DI0>:INTerleaver \n
		Snippet: value: bool = driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.tchannel.interleaver.get(channelNull = repcap.ChannelNull.Default, transportChannelNull = repcap.TransportChannelNull.Default) \n
		The command activates or deactivates channel coding interleaver state 1 for the selected channel. Interleaver state 1 can
		be activated and deactivated for each transport channel individually. The channel is selected via the suffix at TCHannel.
		Interleaver state 2 can only be activated or deactivated for all the transport channels together
		([:SOURce<hw>]:BB:W3GPp:BSTation:ENHanced:CHANnel<ch0>:DPCH:INTerleaver2) . Note: The interleaver states do not cause the
		symbol rate to change. \n
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:param transportChannelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Tchannel')
			:return: interleaver: ON| OFF"""
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		transportChannelNull_cmd_val = self._base.get_repcap_cmd_value(transportChannelNull, repcap.TransportChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:TCHannel{transportChannelNull_cmd_val}:INTerleaver?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Speed:
	"""Speed commands group definition. 6 total commands, 0 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("speed", core, parent)

	def get_cruise(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:SPEed:CRUise \n
		Snippet: value: float = driver.source.fsimulator.dsSimulation.towerToAir.speed.get_cruise() \n
		No command help available \n
			:return: speed_cruise: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:SPEed:CRUise?')
		return Conversions.str_to_float(response)

	def set_cruise(self, speed_cruise: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:SPEed:CRUise \n
		Snippet: driver.source.fsimulator.dsSimulation.towerToAir.speed.set_cruise(speed_cruise = 1.0) \n
		No command help available \n
			:param speed_cruise: No help available
		"""
		param = Conversions.decimal_value_to_str(speed_cruise)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:SPEed:CRUise {param}')

	def get_departure(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:SPEed:DEParture \n
		Snippet: value: float = driver.source.fsimulator.dsSimulation.towerToAir.speed.get_departure() \n
		No command help available \n
			:return: speed_departure: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:SPEed:DEParture?')
		return Conversions.str_to_float(response)

	def set_departure(self, speed_departure: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:SPEed:DEParture \n
		Snippet: driver.source.fsimulator.dsSimulation.towerToAir.speed.set_departure(speed_departure = 1.0) \n
		No command help available \n
			:param speed_departure: No help available
		"""
		param = Conversions.decimal_value_to_str(speed_departure)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:SPEed:DEParture {param}')

	def get_descent(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:SPEed:DESCent \n
		Snippet: value: float = driver.source.fsimulator.dsSimulation.towerToAir.speed.get_descent() \n
		No command help available \n
			:return: speed_descent: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:SPEed:DESCent?')
		return Conversions.str_to_float(response)

	def set_descent(self, speed_descent: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:SPEed:DESCent \n
		Snippet: driver.source.fsimulator.dsSimulation.towerToAir.speed.set_descent(speed_descent = 1.0) \n
		No command help available \n
			:param speed_descent: No help available
		"""
		param = Conversions.decimal_value_to_str(speed_descent)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:SPEed:DESCent {param}')

	def get_start(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:SPEed:STARt \n
		Snippet: value: float = driver.source.fsimulator.dsSimulation.towerToAir.speed.get_start() \n
		No command help available \n
			:return: speed_start: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:SPEed:STARt?')
		return Conversions.str_to_float(response)

	def set_start(self, speed_start: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:SPEed:STARt \n
		Snippet: driver.source.fsimulator.dsSimulation.towerToAir.speed.set_start(speed_start = 1.0) \n
		No command help available \n
			:param speed_start: No help available
		"""
		param = Conversions.decimal_value_to_str(speed_start)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:SPEed:STARt {param}')

	def get_takeoff(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:SPEed:TAKeoff \n
		Snippet: value: float = driver.source.fsimulator.dsSimulation.towerToAir.speed.get_takeoff() \n
		No command help available \n
			:return: speed_takeoff: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:SPEed:TAKeoff?')
		return Conversions.str_to_float(response)

	def set_takeoff(self, speed_takeoff: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:SPEed:TAKeoff \n
		Snippet: driver.source.fsimulator.dsSimulation.towerToAir.speed.set_takeoff(speed_takeoff = 1.0) \n
		No command help available \n
			:param speed_takeoff: No help available
		"""
		param = Conversions.decimal_value_to_str(speed_takeoff)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:SPEed:TAKeoff {param}')

	def get_touchdown(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:SPEed:TOUChdown \n
		Snippet: value: float = driver.source.fsimulator.dsSimulation.towerToAir.speed.get_touchdown() \n
		No command help available \n
			:return: speed_touchdown: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:SPEed:TOUChdown?')
		return Conversions.str_to_float(response)

	def set_touchdown(self, speed_touchdown: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:SPEed:TOUChdown \n
		Snippet: driver.source.fsimulator.dsSimulation.towerToAir.speed.set_touchdown(speed_touchdown = 1.0) \n
		No command help available \n
			:param speed_touchdown: No help available
		"""
		param = Conversions.decimal_value_to_str(speed_touchdown)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:SPEed:TOUChdown {param}')



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ai15:
	"""Ai15 commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ai15", core, parent)

	def set(self, alloc_dci_ai_15: int, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default, indexNull=repcap.IndexNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CH0>:SUBF<ST0>:USER<DIR0>:BWPart<GR0>:ALLoc<USER0>:CS:DCI<S2US0>:AI15 \n
		Snippet: driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.cs.dci.ai15.set(alloc_dci_ai_15 = 1, cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default, indexNull = repcap.IndexNull.Default) \n
		Sets the bit length of the availability indication DCI field for DCI format 2_5. \n
			:param alloc_dci_ai_15: integer Range: 0 to 7
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Dci')"""
		param = Conversions.decimal_value_to_str(alloc_dci_ai_15)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._base.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		indexNull_cmd_val = self._base.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:CS:DCI{indexNull_cmd_val}:AI15 {param}')

	def get(self, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default, indexNull=repcap.IndexNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CH0>:SUBF<ST0>:USER<DIR0>:BWPart<GR0>:ALLoc<USER0>:CS:DCI<S2US0>:AI15 \n
		Snippet: value: int = driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.cs.dci.ai15.get(cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default, indexNull = repcap.IndexNull.Default) \n
		Sets the bit length of the availability indication DCI field for DCI format 2_5. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Dci')
			:return: alloc_dci_ai_15: No help available"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._base.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		indexNull_cmd_val = self._base.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:CS:DCI{indexNull_cmd_val}:AI15?')
		return Conversions.str_to_int(response)



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Setting:
	"""Setting commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("setting", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:OFDM:SETTing:CATalog \n
		Snippet: value: List[str] = driver.source.bb.ofdm.setting.get_catalog() \n
		Queries the files with settings in the default directory. Listed are files with the file extension *.c5g.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:return: c_5_gcat_name: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:OFDM:SETTing:CATalog?')
		return Conversions.str_to_str_list(response)

	def get_del_py(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:OFDM:SETTing:DEL \n
		Snippet: value: str = driver.source.bb.ofdm.setting.get_del_py() \n
		Deletes the selected file from the default or specified directory. Deleted are files with the file extension *.c5g. Refer
		to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default and in
		a specific directory. \n
			:return: filename: string file name or complete file path; file extension can be omitted
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:OFDM:SETTing:DEL?')
		return trim_str_response(response)

	def set_del_py(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:OFDM:SETTing:DEL \n
		Snippet: driver.source.bb.ofdm.setting.set_del_py(filename = '1') \n
		Deletes the selected file from the default or specified directory. Deleted are files with the file extension *.c5g. Refer
		to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default and in
		a specific directory. \n
			:param filename: string file name or complete file path; file extension can be omitted
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:OFDM:SETTing:DEL {param}')

	def get_load(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:OFDM:SETTing:LOAD \n
		Snippet: value: str = driver.source.bb.ofdm.setting.get_load() \n
		Loads the selected file from the default or the specified directory. Loaded are files with extension *.c5g.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:return: filename: string file name or complete file path; file extension can be omitted
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:OFDM:SETTing:LOAD?')
		return trim_str_response(response)

	def set_load(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:OFDM:SETTing:LOAD \n
		Snippet: driver.source.bb.ofdm.setting.set_load(filename = '1') \n
		Loads the selected file from the default or the specified directory. Loaded are files with extension *.c5g.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param filename: string file name or complete file path; file extension can be omitted
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:OFDM:SETTing:LOAD {param}')

	def get_store(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:OFDM:SETTing:STORe \n
		Snippet: value: str = driver.source.bb.ofdm.setting.get_store() \n
		Stores the current settings into the selected file; the file extension (*.c5g) is assigned automatically.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:return: filename: string file name or complete file path
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:OFDM:SETTing:STORe?')
		return trim_str_response(response)

	def set_store(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:OFDM:SETTing:STORe \n
		Snippet: driver.source.bb.ofdm.setting.set_store(filename = '1') \n
		Stores the current settings into the selected file; the file extension (*.c5g) is assigned automatically.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param filename: string file name or complete file path
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:OFDM:SETTing:STORe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Offset:
	"""Offset commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("offset", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	def set(self, offset: float, channel=repcap.Channel.Default) -> None:
		"""SCPI: SENSe<CH>:[POWer]:OFFSet \n
		Snippet: driver.sense.power.offset.set(offset = 1.0, channel = repcap.Channel.Default) \n
		Sets a level offset which is added to the measured level value after activation with command OFFSet:STATe. The level
		offset allows, e.g. to consider an attenuator in the signal path. \n
			:param offset: float Range: -100.0 to 100.0, Unit: dB
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')"""
		param = Conversions.decimal_value_to_str(offset)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SENSe{channel_cmd_val}:POWer:OFFSet {param}')

	def get(self, channel=repcap.Channel.Default) -> float:
		"""SCPI: SENSe<CH>:[POWer]:OFFSet \n
		Snippet: value: float = driver.sense.power.offset.get(channel = repcap.Channel.Default) \n
		Sets a level offset which is added to the measured level value after activation with command OFFSet:STATe. The level
		offset allows, e.g. to consider an attenuator in the signal path. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')
			:return: offset: float Range: -100.0 to 100.0, Unit: dB"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SENSe{channel_cmd_val}:POWer:OFFSet?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'Offset':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Offset(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Location:
	"""Location commands group definition. 6 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("location", core, parent)

	@property
	def coordinates(self):
		"""coordinates commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_coordinates'):
			from .Coordinates import Coordinates
			self._coordinates = Coordinates(self._core, self._base)
		return self._coordinates

	def get_uradius(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GALileo:LOCation:URADius \n
		Snippet: value: int = driver.source.bb.gnss.adGeneration.galileo.location.get_uradius() \n
		Sets the Uncertainty Radius, i.e. sets the maximum radius of the area within which the two-dimensional location of the UE
		is bounded. \n
			:return: radius: integer Range: 0 to 1.E6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:ADGeneration:GALileo:LOCation:URADius?')
		return Conversions.str_to_int(response)

	def set_uradius(self, radius: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GALileo:LOCation:URADius \n
		Snippet: driver.source.bb.gnss.adGeneration.galileo.location.set_uradius(radius = 1) \n
		Sets the Uncertainty Radius, i.e. sets the maximum radius of the area within which the two-dimensional location of the UE
		is bounded. \n
			:param radius: integer Range: 0 to 1.E6
		"""
		param = Conversions.decimal_value_to_str(radius)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ADGeneration:GALileo:LOCation:URADius {param}')

	def clone(self) -> 'Location':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Location(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Direction:
	"""Direction commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("direction", core, parent)

	def set(self, direction: enums.RegObjDir, objectIx=repcap.ObjectIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:OBJect<CH>:DIRection \n
		Snippet: driver.source.regenerator.object.direction.set(direction = enums.RegObjDir.APPRoaching, objectIx = repcap.ObjectIx.Default) \n
		Sets the object direction of a static+moving object. \n
			:param direction: APPRoaching| DEParting
			:param objectIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Object')"""
		param = Conversions.enum_scalar_to_str(direction, enums.RegObjDir)
		objectIx_cmd_val = self._base.get_repcap_cmd_value(objectIx, repcap.ObjectIx)
		self._core.io.write(f'SOURce<HwInstance>:REGenerator:OBJect{objectIx_cmd_val}:DIRection {param}')

	# noinspection PyTypeChecker
	def get(self, objectIx=repcap.ObjectIx.Default) -> enums.RegObjDir:
		"""SCPI: [SOURce<HW>]:REGenerator:OBJect<CH>:DIRection \n
		Snippet: value: enums.RegObjDir = driver.source.regenerator.object.direction.get(objectIx = repcap.ObjectIx.Default) \n
		Sets the object direction of a static+moving object. \n
			:param objectIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Object')
			:return: direction: APPRoaching| DEParting"""
		objectIx_cmd_val = self._base.get_repcap_cmd_value(objectIx, repcap.ObjectIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:REGenerator:OBJect{objectIx_cmd_val}:DIRection?')
		return Conversions.str_to_scalar_enum(response, enums.RegObjDir)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class File:
	"""File commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("file", core, parent)

	def get_constellation(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:IMPort:NAVic:FILE:CONStellation \n
		Snippet: value: str = driver.source.bb.gnss.sv.importPy.navic.file.get_constellation() \n
		Selects the file from that the satellites constellation and navigation data are extracted. Supported file types per GNSS
		system
			Table Header: GNSS system / *.txt / *.alm / *.al3 / *.xml / *.alg / *.rnx / *.<xx>n \n
			- GPS / x / x / x / x / x
			- Galileo / x / x / x / x / x / x
			- GLONASS / x / x / x
			- BeiDou / x / x / x
			- QZSS / x / x / x / x
			- NavIC / x
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:return: filename: string Filename, including file path and file extension.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SV:IMPort:NAVic:FILE:CONStellation?')
		return trim_str_response(response)

	def set_constellation(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:IMPort:NAVic:FILE:CONStellation \n
		Snippet: driver.source.bb.gnss.sv.importPy.navic.file.set_constellation(filename = '1') \n
		Selects the file from that the satellites constellation and navigation data are extracted. Supported file types per GNSS
		system
			Table Header: GNSS system / *.txt / *.alm / *.al3 / *.xml / *.alg / *.rnx / *.<xx>n \n
			- GPS / x / x / x / x / x
			- Galileo / x / x / x / x / x / x
			- GLONASS / x / x / x
			- BeiDou / x / x / x
			- QZSS / x / x / x / x
			- NavIC / x
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param filename: string Filename, including file path and file extension.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:IMPort:NAVic:FILE:CONStellation {param}')

	def get_nmessage(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:IMPort:NAVic:FILE:NMESsage \n
		Snippet: value: str = driver.source.bb.gnss.sv.importPy.navic.file.get_nmessage() \n
		Selects the file from that the navigation data is extracted. For overview of the supported file types, see Table
		'Supported file types per GNSS system'. Refer to 'Accessing Files in the Default or Specified Directory' for general
		information on file handling in the default and in a specific directory. \n
			:return: filename: string Filename, incl. file path and file extension.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SV:IMPort:NAVic:FILE:NMESsage?')
		return trim_str_response(response)

	def set_nmessage(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:IMPort:NAVic:FILE:NMESsage \n
		Snippet: driver.source.bb.gnss.sv.importPy.navic.file.set_nmessage(filename = '1') \n
		Selects the file from that the navigation data is extracted. For overview of the supported file types, see Table
		'Supported file types per GNSS system'. Refer to 'Accessing Files in the Default or Specified Directory' for general
		information on file handling in the default and in a specific directory. \n
			:param filename: string Filename, incl. file path and file extension.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:IMPort:NAVic:FILE:NMESsage {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rf:
	"""Rf commands group definition. 26 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rf", core, parent)

	@property
	def optimization(self):
		"""optimization commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_optimization'):
			from .Optimization import Optimization
			self._optimization = Optimization(self._core, self._base)
		return self._optimization

	@property
	def user(self):
		"""user commands group. 4 Sub-classes, 4 commands."""
		if not hasattr(self, '_user'):
			from .User import User
			self._user = User(self._core, self._base)
		return self._user

	def clone(self) -> 'Rf':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Rf(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fsk:
	"""Fsk commands group definition. 3 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fsk", core, parent)

	@property
	def variable(self):
		"""variable commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_variable'):
			from .Variable import Variable
			self._variable = Variable(self._core, self._base)
		return self._variable

	def get_deviation(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:DM:FSK:DEViation \n
		Snippet: value: float = driver.source.bb.dm.fsk.get_deviation() \n
		Sets the frequency deviation when FSK modulation is selected. \n
			:return: deviation: float The value range depends on the symbol rate. Range: 1 to 40E6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DM:FSK:DEViation?')
		return Conversions.str_to_float(response)

	def set_deviation(self, deviation: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:DM:FSK:DEViation \n
		Snippet: driver.source.bb.dm.fsk.set_deviation(deviation = 1.0) \n
		Sets the frequency deviation when FSK modulation is selected. \n
			:param deviation: float The value range depends on the symbol rate. Range: 1 to 40E6
		"""
		param = Conversions.decimal_value_to_str(deviation)
		self._core.io.write(f'SOURce<HwInstance>:BB:DM:FSK:DEViation {param}')

	def clone(self) -> 'Fsk':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Fsk(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mimo:
	"""Mimo commands group definition. 427 total commands, 6 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mimo", core, parent)

	@property
	def antenna(self):
		"""antenna commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_antenna'):
			from .Antenna import Antenna
			self._antenna = Antenna(self._core, self._base)
		return self._antenna

	@property
	def copy(self):
		"""copy commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_copy'):
			from .Copy import Copy
			self._copy = Copy(self._core, self._base)
		return self._copy

	@property
	def power(self):
		"""power commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def scwi(self):
		"""scwi commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_scwi'):
			from .Scwi import Scwi
			self._scwi = Scwi(self._core, self._base)
		return self._scwi

	@property
	def tap(self):
		"""tap commands group. 5 Sub-classes, 1 commands."""
		if not hasattr(self, '_tap'):
			from .Tap import Tap
			self._tap = Tap(self._core, self._base)
		return self._tap

	@property
	def tgn(self):
		"""tgn commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_tgn'):
			from .Tgn import Tgn
			self._tgn = Tgn(self._core, self._base)
		return self._tgn

	def get_capability(self) -> str:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:CAPability \n
		Snippet: value: str = driver.source.fsimulator.mimo.get_capability() \n
		Queries the supported MIMO configurations. \n
			:return: mimo_capability: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:MIMO:CAPability?')
		return trim_str_response(response)

	def copy_all(self) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:COPY:ALL \n
		Snippet: driver.source.fsimulator.mimo.copy_all() \n
		Applies the matrix values of the current tap to all taps. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:MIMO:COPY:ALL')

	def copy_all_with_opc(self) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:COPY:ALL \n
		Snippet: driver.source.fsimulator.mimo.copy_all_with_opc() \n
		Applies the matrix values of the current tap to all taps. \n
		Same as copy_all, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:FSIMulator:MIMO:COPY:ALL')

	def set_md_load(self, md_load: str) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:MDLoad \n
		Snippet: driver.source.fsimulator.mimo.set_md_load(md_load = '1') \n
		Loads file with saved MIMO settings. \n
			:param md_load: string
		"""
		param = Conversions.value_to_quoted_str(md_load)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:MIMO:MDLoad {param}')

	def set_md_store(self, md_store: str) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:MDSTore \n
		Snippet: driver.source.fsimulator.mimo.set_md_store(md_store = '1') \n
		Saves the MIMO settings in a file. \n
			:param md_store: string
		"""
		param = Conversions.value_to_quoted_str(md_store)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:MIMO:MDSTore {param}')

	def get_mpower(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:MPOWer \n
		Snippet: value: float = driver.source.fsimulator.mimo.get_mpower() \n
		No command help available \n
			:return: mpower: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:MIMO:MPOWer?')
		return Conversions.str_to_float(response)

	def set_mpower(self, mpower: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:MPOWer \n
		Snippet: driver.source.fsimulator.mimo.set_mpower(mpower = 1.0) \n
		No command help available \n
			:param mpower: No help available
		"""
		param = Conversions.decimal_value_to_str(mpower)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:MIMO:MPOWer {param}')

	# noinspection PyTypeChecker
	def get_subset(self) -> enums.FadMimoSubSet:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:SUBSet \n
		Snippet: value: enums.FadMimoSubSet = driver.source.fsimulator.mimo.get_subset() \n
		In 8x8 MIMO configuration, sets the subset of MIMO channels that is calculated by the particular R&S SMW. \n
			:return: subset: SET2| SET1 | ALL
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:MIMO:SUBSet?')
		return Conversions.str_to_scalar_enum(response, enums.FadMimoSubSet)

	def set_subset(self, subset: enums.FadMimoSubSet) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:SUBSet \n
		Snippet: driver.source.fsimulator.mimo.set_subset(subset = enums.FadMimoSubSet.ALL) \n
		In 8x8 MIMO configuration, sets the subset of MIMO channels that is calculated by the particular R&S SMW. \n
			:param subset: SET2| SET1 | ALL
		"""
		param = Conversions.enum_scalar_to_str(subset, enums.FadMimoSubSet)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:MIMO:SUBSet {param}')

	def clone(self) -> 'Mimo':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Mimo(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Measure:
	"""Measure commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("measure", core, parent)

	def get(self, force: str = None) -> bool:
		"""SCPI: CALibration<HW>:LEVel:[MEASure] \n
		Snippet: value: bool = driver.calibration.level.measure.get(force = '1') \n
		No command help available \n
			:param force: No help available
			:return: measure: No help available"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('force', force, DataType.String, True))
		response = self._core.io.query_str(f'CALibration<HwInstance>:LEVel:MEASure? {param}'.rstrip())
		return Conversions.str_to_bool(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Aval:
	"""Aval commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("aval", core, parent)

	def get(self, allocation_value: int) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MBSFn:AI:MCCH:AVAL \n
		Snippet: value: int = driver.source.bb.eutra.downlink.mbsfn.ai.mcch.aval.get(allocation_value = 1) \n
		Indicates the subframes of the radio frames indicated by the 'MCCH repetition period' and the 'MCCH offset', that may
		carry MCCH. \n
			:param allocation_value: integer
			:return: allocation_value: integer"""
		param = Conversions.decimal_value_to_str(allocation_value)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:MBSFn:AI:MCCH:AVAL? {param}')
		return Conversions.str_to_int(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Speriod:
	"""Speriod commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("speriod", core, parent)

	def get(self, mobileStation=repcap.MobileStation.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:PRACh:TIMing:SPERiod \n
		Snippet: value: float = driver.source.bb.w3Gpp.mstation.prach.timing.speriod.get(mobileStation = repcap.MobileStation.Default) \n
		Queries the structure length. \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:return: speriod: float"""
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:PRACh:TIMing:SPERiod?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Calibrated:
	"""Calibrated commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("calibrated", core, parent)

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	def get_frequency(self) -> float:
		"""SCPI: SOURce<HW>:RFALignment:CALibrated:FREQuency \n
		Snippet: value: float = driver.source.rfAlignment.calibrated.get_frequency() \n
		Queries the frequency for that the calibration data is valid. \n
			:return: calibrated_freq: float
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:RFALignment:CALibrated:FREQuency?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'Calibrated':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Calibrated(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fcontrol:
	"""Fcontrol commands group definition. 12 total commands, 11 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fcontrol", core, parent)

	@property
	def fds(self):
		"""fds commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fds'):
			from .Fds import Fds
			self._fds = Fds(self._core, self._base)
		return self._fds

	@property
	def mdata(self):
		"""mdata commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mdata'):
			from .Mdata import Mdata
			self._mdata = Mdata(self._core, self._base)
		return self._mdata

	@property
	def mfragments(self):
		"""mfragments commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mfragments'):
			from .Mfragments import Mfragments
			self._mfragments = Mfragments(self._core, self._base)
		return self._mfragments

	@property
	def order(self):
		"""order commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_order'):
			from .Order import Order
			self._order = Order(self._core, self._base)
		return self._order

	@property
	def pmanagement(self):
		"""pmanagement commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pmanagement'):
			from .Pmanagement import Pmanagement
			self._pmanagement = Pmanagement(self._core, self._base)
		return self._pmanagement

	@property
	def pversion(self):
		"""pversion commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pversion'):
			from .Pversion import Pversion
			self._pversion = Pversion(self._core, self._base)
		return self._pversion

	@property
	def retry(self):
		"""retry commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_retry'):
			from .Retry import Retry
			self._retry = Retry(self._core, self._base)
		return self._retry

	@property
	def subType(self):
		"""subType commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_subType'):
			from .SubType import SubType
			self._subType = SubType(self._core, self._base)
		return self._subType

	@property
	def tds(self):
		"""tds commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tds'):
			from .Tds import Tds
			self._tds = Tds(self._core, self._base)
		return self._tds

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePy
			self._typePy = TypePy(self._core, self._base)
		return self._typePy

	@property
	def wep(self):
		"""wep commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_wep'):
			from .Wep import Wep
			self._wep = Wep(self._core, self._base)
		return self._wep

	def set(self, fcontrol: List[str], frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:MAC:FCONtrol \n
		Snippet: driver.source.bb.wlnn.fblock.user.mac.fcontrol.set(fcontrol = ['raw1', 'raw2', 'raw3'], frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		The command enters the value of the frame control field. The frame control field has a length of 2 bytes (16 bits) and is
		used to define the protocol version, the frame type, and its function, etc.. As an alternative, the individual bits can
		be set with the following commands. \n
			:param fcontrol: integer Range: #H0000,16 to #HFFFF,16
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')"""
		param = Conversions.list_to_csv_str(fcontrol)
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:MAC:FCONtrol {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:MAC:FCONtrol \n
		Snippet: value: List[str] = driver.source.bb.wlnn.fblock.user.mac.fcontrol.get(frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		The command enters the value of the frame control field. The frame control field has a length of 2 bytes (16 bits) and is
		used to define the protocol version, the frame type, and its function, etc.. As an alternative, the individual bits can
		be set with the following commands. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: fcontrol: integer Range: #H0000,16 to #HFFFF,16"""
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:MAC:FCONtrol?')
		return Conversions.str_to_str_list(response)

	def clone(self) -> 'Fcontrol':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Fcontrol(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cw:
	"""Cw commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cw", core, parent)

	def get_foffset(self) -> float:
		"""SCPI: [SOURce]:BB:W3GPp:TS25141:IFSignal:CW:FOFFset \n
		Snippet: value: float = driver.source.bb.w3Gpp.ts25141.ifRignal.cw.get_foffset() \n
		Sets frequency offset of the CW interfering signal versus the wanted signal RF frequency. \n
			:return: foffset: float
		"""
		response = self._core.io.query_str('SOURce:BB:W3GPp:TS25141:IFSignal:CW:FOFFset?')
		return Conversions.str_to_float(response)

	def set_foffset(self, foffset: float) -> None:
		"""SCPI: [SOURce]:BB:W3GPp:TS25141:IFSignal:CW:FOFFset \n
		Snippet: driver.source.bb.w3Gpp.ts25141.ifRignal.cw.set_foffset(foffset = 1.0) \n
		Sets frequency offset of the CW interfering signal versus the wanted signal RF frequency. \n
			:param foffset: float
		"""
		param = Conversions.decimal_value_to_str(foffset)
		self._core.io.write(f'SOURce:BB:W3GPp:TS25141:IFSignal:CW:FOFFset {param}')

	def get_power(self) -> float:
		"""SCPI: [SOURce]:BB:W3GPp:TS25141:IFSignal:CW:POWer \n
		Snippet: value: float = driver.source.bb.w3Gpp.ts25141.ifRignal.cw.get_power() \n
		Sets the RF level of the CW interfering signal. \n
			:return: power: float
		"""
		response = self._core.io.query_str('SOURce:BB:W3GPp:TS25141:IFSignal:CW:POWer?')
		return Conversions.str_to_float(response)

	def set_power(self, power: float) -> None:
		"""SCPI: [SOURce]:BB:W3GPp:TS25141:IFSignal:CW:POWer \n
		Snippet: driver.source.bb.w3Gpp.ts25141.ifRignal.cw.set_power(power = 1.0) \n
		Sets the RF level of the CW interfering signal. \n
			:param power: float
		"""
		param = Conversions.decimal_value_to_str(power)
		self._core.io.write(f'SOURce:BB:W3GPp:TS25141:IFSignal:CW:POWer {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce]:BB:W3GPp:TS25141:IFSignal:CW:STATe \n
		Snippet: value: bool = driver.source.bb.w3Gpp.ts25141.ifRignal.cw.get_state() \n
		This command enable/disables the CW interfering signal. In mode 'According to Standard' (SOURce:BB:W3GPp:TS25141:EMODe
		STANdard) , the value is fixed to ON. Sets commands method RsSmw.Source.Awgn.cnRatio and method RsSmw.Source.Awgn.Power.
		Noise.value after execution of method RsSmw.Source.Bb.W3Gpp.Ts25141.Tcase.Execute.set \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce:BB:W3GPp:TS25141:IFSignal:CW:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce]:BB:W3GPp:TS25141:IFSignal:CW:STATe \n
		Snippet: driver.source.bb.w3Gpp.ts25141.ifRignal.cw.set_state(state = False) \n
		This command enable/disables the CW interfering signal. In mode 'According to Standard' (SOURce:BB:W3GPp:TS25141:EMODe
		STANdard) , the value is fixed to ON. Sets commands method RsSmw.Source.Awgn.cnRatio and method RsSmw.Source.Awgn.Power.
		Noise.value after execution of method RsSmw.Source.Bb.W3Gpp.Ts25141.Tcase.Execute.set \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce:BB:W3GPp:TS25141:IFSignal:CW:STATe {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rt:
	"""Rt commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rt", core, parent)

	def get_changes(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:RT:CHANges \n
		Snippet: value: bool = driver.source.bb.gnss.logging.rt.get_changes() \n
		No command help available \n
			:return: status: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:RT:CHANges?')
		return Conversions.str_to_bool(response)

	def set_changes(self, status: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:RT:CHANges \n
		Snippet: driver.source.bb.gnss.logging.rt.set_changes(status = False) \n
		No command help available \n
			:param status: No help available
		"""
		param = Conversions.bool_to_str(status)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:RT:CHANges {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:RT:STATe \n
		Snippet: value: bool = driver.source.bb.gnss.logging.rt.get_state() \n
		Starts real-time data logging. \n
			:return: status: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:RT:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, status: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:RT:STATe \n
		Snippet: driver.source.bb.gnss.logging.rt.set_state(status = False) \n
		Starts real-time data logging. \n
			:param status: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(status)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:RT:STATe {param}')



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Azp:
	"""Azp commands group definition. 12 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("azp", core, parent)

	@property
	def nsets(self):
		"""nsets commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nsets'):
			from .Nsets import Nsets
			self._nsets = Nsets(self._core, self._base)
		return self._nsets

	@property
	def set(self):
		"""set commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_set'):
			from .Set import Set
			self._set = Set(self._core, self._base)
		return self._set

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	def clone(self) -> 'Azp':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Azp(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ccoding:
	"""Ccoding commands group definition. 6 total commands, 6 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ccoding", core, parent)

	@property
	def icqiOffset(self):
		"""icqiOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_icqiOffset'):
			from .IcqiOffset import IcqiOffset
			self._icqiOffset = IcqiOffset(self._core, self._base)
		return self._icqiOffset

	@property
	def iharqOffset(self):
		"""iharqOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iharqOffset'):
			from .IharqOffset import IharqOffset
			self._iharqOffset = IharqOffset(self._core, self._base)
		return self._iharqOffset

	@property
	def iriOffset(self):
		"""iriOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iriOffset'):
			from .IriOffset import IriOffset
			self._iriOffset = IriOffset(self._core, self._base)
		return self._iriOffset

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import Mode
			self._mode = Mode(self._core, self._base)
		return self._mode

	@property
	def ocqiMin(self):
		"""ocqiMin commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ocqiMin'):
			from .OcqiMin import OcqiMin
			self._ocqiMin = OcqiMin(self._core, self._base)
		return self._ocqiMin

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	def clone(self) -> 'Ccoding':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Ccoding(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPy:
	"""ListPy commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("listPy", core, parent)

	def get_state(self) -> bool:
		"""SCPI: OUTPut<HW>:BLANk:LIST:STATe \n
		Snippet: value: bool = driver.output.blank.listPy.get_state() \n
		Activates RF output blanking. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('OUTPut<HwInstance>:BLANk:LIST:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: OUTPut<HW>:BLANk:LIST:STATe \n
		Snippet: driver.output.blank.listPy.set_state(state = False) \n
		Activates RF output blanking. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'OUTPut<HwInstance>:BLANk:LIST:STATe {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Protation:
	"""Protation commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("protation", core, parent)

	def set(self, protation: enums.TdscdmaPhasRot, cell=repcap.Cell.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:CELL<ST>:PROTation \n
		Snippet: driver.source.bb.tdscdma.down.cell.protation.set(protation = enums.TdscdmaPhasRot.AUTO, cell = repcap.Cell.Default) \n
		Selects the phase rotation for the downlink pilots. \n
			:param protation: AUTO| S1| S2 AUTO Default phase rotation sequence according to the presence of the P-CCPCH. S1 There is a P-CCPCH in the next four subframes. S2 There is no P-CCPCH in the next four subframes.
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')"""
		param = Conversions.enum_scalar_to_str(protation, enums.TdscdmaPhasRot)
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:DOWN:CELL{cell_cmd_val}:PROTation {param}')

	# noinspection PyTypeChecker
	def get(self, cell=repcap.Cell.Default) -> enums.TdscdmaPhasRot:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:CELL<ST>:PROTation \n
		Snippet: value: enums.TdscdmaPhasRot = driver.source.bb.tdscdma.down.cell.protation.get(cell = repcap.Cell.Default) \n
		Selects the phase rotation for the downlink pilots. \n
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: protation: AUTO| S1| S2 AUTO Default phase rotation sequence according to the presence of the P-CCPCH. S1 There is a P-CCPCH in the next four subframes. S2 There is no P-CCPCH in the next four subframes."""
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TDSCdma:DOWN:CELL{cell_cmd_val}:PROTation?')
		return Conversions.str_to_scalar_enum(response, enums.TdscdmaPhasRot)
